@@ -1,6 +1,8 @@
 pub mod actions;
 pub mod activity;
 pub mod current;
+pub mod events;
+pub mod gists;
 pub mod gitignore;
 pub mod issues;
 pub mod licenses;
